ReflexCommand

Enum ReflexCommand 

pub enum ReflexCommand {
    Add {
        name: String,
        description: String,
        trigger_type: String,
        trigger_config: String,
        action_type: String,
        action_config: String,
        status: String,
        tags: String,
        dir: Option<String>,
    },
    Update {
        id: String,
        name: Option<String>,
        description: Option<String>,
        trigger_type: Option<String>,
        trigger_config: Option<String>,
        action_type: Option<String>,
        action_config: Option<String>,
        status: Option<String>,
        tags: Option<String>,
    },
    Get {
        id: String,
    },
    List {
        status: Option<String>,
        scope: Option<String>,
        tags: Option<String>,
        name_search: Option<String>,
        dir: Option<String>,
    },
    Delete {
        id: String,
    },
    Run {
        id: Option<String>,
        trigger_type: Option<String>,
        limit: usize,
    },
    AddHeartbeatLoop {
        name: String,
        agent: Option<String>,
        max_claims: usize,
        tags: String,
        dir: Option<String>,
    },
    AddHumanTriggerLoop {
        name: String,
        agent: Option<String>,
        task_title: String,
        priority: String,
        max_tasks: usize,
        tags: String,
        dir: Option<String>,
    },
    AddHealthTrigger {
        name: String,
        agent: Option<String>,
        watch_states: String,
        priority: String,
        tags: String,
        dir: Option<String>,
    },
}

Variants



Add

Add a new reflex entry.

Fields

description: String
trigger_type: String
trigger_config: String
action_type: String
action_config: String
status: String


Update

Update an existing reflex entry.

Fields

description: Option<String>
trigger_type: Option<String>
trigger_config: Option<String>
action_type: Option<String>
action_config: Option<String>


Get

Retrieve a reflex entry by ID.

Fields



List

List reflex entries.



Delete

Delete a reflex entry.

Fields



Run

Run active reflex actions by id or trigger type.

Fields

trigger_type: Option<String>


AddHeartbeatLoop

Install a canonical human-triggered heartbeat autoclaim reflex.



AddHumanTriggerLoop

Install a human trigger loop reflex (trigger -> task -> worker run -> lesson).

Fields

task_title: String
priority: String
max_tasks: usize


AddHealthTrigger

Install a condition-based health trigger reflex that creates remediation tasks when health claims enter STALE or CONTRADICTED states.

Fields

watch_states: String

Health states that trigger remediation (comma-separated: STALE,CONTRADICTED)

priority: String